<p align="center">
  <a href="https://v2.nonebot.dev/"><img src="https://raw.githubusercontent.com/nonebot/nonebot2/master/docs/.vuepress/public/logo.png" width="200" height="200" alt="nonebot"></a>
</p>

<div align="center">

# 在线运行代码<_

_✨ NoneBot2 在线运行代码<_ ✨_

</div>
运行于[https://glot.io/](https://glot.io/)

## 安装💿
`pip install nonebot-plugin-code`


## 导入📲
在**bot.py** 导入，语句：
`nonebot.load_plugin("nonebot_plugin_code")`



## 指令💻
```
code [语言] [-i] [inputText]
[代码]

-i：可选 输入 后跟输入内容

运行代码示例(python)(无输入)：
    code py
        print("sb")
运行代码示例(python)(有输入)：
    code py -i 你好
        print(input())
```


**给个star吧~**

其他插件
[it咨询](https://github.com/yzyyz1387/nonebot_plugin_itnews "it资讯")
[工作性价比](https://github.com/yzyyz1387/nonebot_plugin_workscore)

## 截图🖼

![](https://cdn.jsdelivr.net/gh/yzyyz1387/blogimages/nonebot_plugin_code.png)




